### Generics for ppstat. 

setGeneric("anticipating", function(model, ...) standardGeneric("anticipating"))
setGeneric("coefficients<-", function(model, value) standardGeneric("coefficients<-"))
setGeneric("computeLinearPredictor", function(model, ...) standardGeneric("computeLinearPredictor"))
setGeneric("computeBasis", function(model, ...) standardGeneric("computeBasis"))
setGeneric("computeMinusLogLikelihood", function(model, coefficients=NULL, ...) standardGeneric("computeMinusLogLikelihood"))
setGeneric("computeDMinusLogLikelihood", function(model, coefficients=NULL, ...) standardGeneric("computeDMinusLogLikelihood"))
setGeneric("computeDDMinusLogLikelihood", function(model, coefficients=NULL, ...) standardGeneric("computeDDMinusLogLikelihood"))
setGeneric("computeModelMatrix", function(model, evaluationPositions=NULL, ...) standardGeneric("computeModelMatrix"))
setGeneric("computeRecurrenceMatrix", function(model, evaluationPositions = NULL, A = 1000, ...) standardGeneric("computeRecurrenceMatrix"))
setGeneric("computeWeights", function(model, coefficients=NULL, ...) standardGeneric("computeWeights"))
setGeneric("computeWorkingResponse", function(model, coefficients=NULL, ...) standardGeneric("computeWorkingResponse"))
setGeneric("computeVar", function(model, ...) standardGeneric("computeVar"))
setGeneric("formula<-", function(model, value) standardGeneric("formula<-"))
setGeneric("getAssign", function(model, ...) standardGeneric("getAssign"))
setGeneric("getAdjacencyMatrix", function(model, ...) standardGeneric("getAdjacencyMatrix"))
setGeneric("getBasis", function(model, term, ...) standardGeneric("getBasis"))
setGeneric("getInformation", function(model, ...) standardGeneric("getInformation"))
setGeneric("getLocalIndependenceGraph", function(model, ...) standardGeneric("getLocalIndependenceGraph"))
setGeneric("getTermPlotData", function(model, ...) standardGeneric("getTermPlotData"))
setGeneric("getFilterTerms", function(model, ...) standardGeneric("getFilterTerms"))
setGeneric("getLinearFilter", function(model, ...) standardGeneric("getLinearFilter"))
setGeneric("getModels", function(model, ...) standardGeneric("getModels"))
setGeneric("getModelMatrix", function(model, col,...) standardGeneric("getModelMatrix"))
setGeneric("getKernelMatrix", function(model, col,...) standardGeneric("getKernelMatrix"))
setGeneric("getModelMatrixEnv", function(model, ...) standardGeneric("getModelMatrixEnv"))
setGeneric("iwlsFit", function(model, ...) standardGeneric("iwlsFit"))
setGeneric("processData", function(model, ...) standardGeneric("processData"))
setGeneric("ppmFit", function(model, ...) standardGeneric("ppmFit"))
setGeneric("optimFit", function(model, ...) standardGeneric("optimFit"))
setGeneric("glmFit", function(model, ...) standardGeneric("glmFit"))
setGeneric("glmnetFit", function(model, ...) standardGeneric("glmnetFit"))
setGeneric("grpLassoFit", function(model, ...) standardGeneric("grpLassoFit"))
setGeneric("lsFit", function(model, ...) standardGeneric("lsFit"))
setGeneric("response", function(model, ...) standardGeneric("response"))
setGeneric("setBasis<-", function(model, term, value) standardGeneric("setBasis<-"))
setGeneric("setModels<-", function(model, value) standardGeneric("setModels<-"))
setGeneric("setFilterTerms<-", function(model, value) standardGeneric("setFilterTerms<-"))
setGeneric("setModelMatrixEnv<-", function(model, value) standardGeneric("setModelMatrixEnv<-"))
setGeneric("simulate", function(model, ...) standardGeneric("simulate"))
setGeneric("stepInformation", function(model, ...) standardGeneric("stepInformation"))
setGeneric("processData<-", function(model, value) standardGeneric("processData<-"))
setGeneric("termPlot", function(model, ...) standardGeneric("termPlot"))
setGeneric("updateKernelMatrix", function(model, ...) standardGeneric("updateKernelMatrix"))
setGeneric("updateModelMatrix", function(model, ...) standardGeneric("updateModelMatrix"))
